SupabaseSerializable class

An annotation used to specify a class to generate Supabase code for.

Creates a serialize/deserialize function for JSON.

Constructors

SupabaseSerializable({bool defaultToNull = true, FieldRename fieldRename = FieldRename.snake, bool ignoreDuplicates = false, String? onConflict, String? tableName})
Creates a new SupabaseSerializable instance.
const

Properties

defaultToNull → bool
Forwards to Supabase's defaultToNull parameter.
final
fieldRename → FieldRename
Defines the automatic naming strategy when converting class field names into JSON map keys.
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreDuplicates → bool
Forwards to Supabase's ignoreDuplicates parameter.
final
onConflict → String?
Forwards to Supabase's onConflict parameter. This should be comma-separated Supabase column names, not Dart fields.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String?
The Supabase table name to fetch from. For example, "users" in Supabase.instance.client.from("users"). The schema name is not required.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaults → const SupabaseSerializable
An instance of SupabaseSerializable with all fields set to their default values.