SupabaseRequest<TModel extends SupabaseModel> class

Construct a request for Supabase data. The primary purpose of this class is to DRY code for URL requests to the SupabaseMockServer. For example: final req = SupabaseRequest<MyModel>();

Constructors

SupabaseRequest({String? tableName, String? fields, String? filter, int? limit, bool realtime = false, String? requestMethod = 'GET'})
Construct a request for Supabase data. The primary purpose of this class is to DRY code for URL requests to the SupabaseMockServer. For example: final req = SupabaseRequest<MyModel>();
const

Properties

fields → String?
If fields are not provided, they will try to be inferred using the SupabaseMockServer's modelDictionary.
final
filter → String?
A PostgREST-style filter, such as id=eq.1
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int?
final
realtime → bool
final
requestMethod → String?
An HTTP request method, e.g. GET, POST, PUT, DELETE
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String?
If a tableName is not provided, it will try to be inferred using the SupabaseMockServer's modelDictionary based on the SupabaseAdapter's supabaseTableName.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toUri(SupabaseModelDictionary? modelDictionary) → Uri
Convert the request to a PostgREST URL

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fieldsFromDictionary<TModel extends SupabaseModel>(SupabaseModelDictionary modelDictionary, {Query? query}) → String
This provides a convenience method to generate fields as the SupabaseProvider would generate them.